@@ -1,31 +1,21 @@
 /*
     This file is part of the KDE games library
-    Copyright (C) 2001 Andreas Beckermann (b_mann@gmx.de)
-    Copyright (C) 2001 Martin Heni (kde at heni-online.de)
+    SPDX-FileCopyrightText: 2001 Andreas Beckermann <b_mann@gmx.de>
+    SPDX-FileCopyrightText: 2001 Martin Heni <kde at heni-online.de>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef __KGAMEPROPERTY_H_
 #define __KGAMEPROPERTY_H_
 
+// own
+#include "libkdegamesprivate_export.h"
+// Qt
 #include <QDataStream>
 #include <QDebug>
-
+// Std
 #include <typeinfo>
-#include "libkdegamesprivate_export.h"
 
 class KGame;
 class KPlayer;
@@ -539,7 +529,7 @@ private:
  *
  * @section Custom classes:
  *
- * If you want to use a custum class with KGameProperty you have to implement the
+ * If you want to use a custom class with KGameProperty you have to implement the
  * operators << and >> for QDataStream:
  * \code
  * class Card
@@ -755,7 +745,7 @@ public:
 	 * Saves the object to a stream.
 	 * @param stream The stream to save to
 	 **/
-	void save(QDataStream &stream) Q_DECL_OVERRIDE
+	void save(QDataStream &stream) override
 	{
 		stream << mData;
 	}
@@ -781,7 +771,7 @@ public:
 	 * Also calls emitSignal if isEmittingSignal is TRUE.
 	 * @param s The stream to read from
 	 **/
-	void load(QDataStream& s) Q_DECL_OVERRIDE
+	void load(QDataStream& s) override
 	{
 		s >> mData;
 		setDirty(false);
@@ -834,7 +824,7 @@ public:
 	 **/
 	operator type() const { return value(); }
 
-	const type_info* typeinfo() Q_DECL_OVERRIDE { return &typeid(type); }
+	const type_info* typeinfo() override { return &typeid(type); }
 
 private:
 	void init() { }
